@@ -50,7 +50,8 @@ func NewExecutorTest(t *testing.T, opts ...ExecutorTestOption) {
 		task: "default",
 		vars: map[string]any{},
 		TaskTest: TaskTest{
-			experiments: map[*experiments.Experiment]int{},
+			experiments:         map[*experiments.Experiment]int{},
+			fixtureTemplateData: map[string]any{},
 		},
 	}
 	// Apply the functional options
@@ -232,7 +233,7 @@ func TestEmptyTaskfile(t *testing.T) {
 			task.WithDir("testdata/empty_taskfile"),
 		),
 		WithSetupError(),
-		WithPostProcessFn(PPRemoveAbsolutePaths),
+		WithFixtureTemplating(),
 	)
 }
 
@@ -367,7 +368,7 @@ func TestSpecialVars(t *testing.T) {
 					task.WithVersionCheck(true),
 				),
 				WithTask(test),
-				WithPostProcessFn(PPRemoveAbsolutePaths),
+				WithFixtureTemplating(),
 			)
 		}
 	}
@@ -551,7 +552,7 @@ func TestStatus(t *testing.T) {
 			task.WithVerbose(true),
 		),
 		WithTask("gen-silent-baz"),
-		WithPostProcessFn(PPRemoveAbsolutePaths),
+		WithFixtureTemplating(),
 	)
 }
 
@@ -777,7 +778,7 @@ func TestForCmds(t *testing.T) {
 				task.WithForce(true),
 			),
 			WithTask(test.name),
-			WithPostProcessFn(PPRemoveAbsolutePaths),
+			WithFixtureTemplating(),
 		}
 		if test.wantErr {
 			opts = append(opts, WithRunError())
@@ -822,7 +823,7 @@ func TestForDeps(t *testing.T) {
 				task.WithOutputStyle(ast.Output{Name: "group"}),
 			),
 			WithTask(test.name),
-			WithPostProcessFn(PPRemoveAbsolutePaths),
+			WithFixtureTemplating(),
 			WithPostProcessFn(PPSortedLines),
 		}
 		if test.wantErr {
@@ -957,6 +958,15 @@ func TestFuzzyModel(t *testing.T) {
 		),
 		WithTask("install"),
 	)
+
+	NewExecutorTest(t,
+		WithName("intern"),
+		WithExecutorOptions(
+			task.WithDir("testdata/fuzzy"),
+		),
+		WithTask("intern"),
+		WithRunError(),
+	)
 }
 
 func TestIncludeChecksum(t *testing.T) {
@@ -975,6 +985,6 @@ func TestIncludeChecksum(t *testing.T) {
 			task.WithDir("testdata/includes_checksum/incorrect"),
 		),
 		WithSetupError(),
-		WithPostProcessFn(PPRemoveAbsolutePaths),
+		WithFixtureTemplating(),
 	)
 }
